@@ -31,30 +31,32 @@
 
 #include "kget_debug.h"
 
+#include <algorithm>
 #include <iostream>
-#include <qinputdialog.h>
-#include <kmessagebox.h>
-#include <klocale.h>
-#include <kservicetypetrader.h>
-#include <kiconloader.h>
-#include <kactioncollection.h>
-#include <kio/renamedialog.h>
-#include <kio/deletejob.h>
+
+#include <KMessageBox>
+#include <KLocalizedString>
+#include <KServiceTypeTrader>
+#include <KIconLoader>
+#include <KActionCollection>
+#include <KIO/RenameDialog>
+#include <KIO/DeleteJob>
 #include <KSharedConfig>
 #include <KPluginInfo>
 #include <KConfigDialog>
-#include <QSaveFile>
 #include <KPluginMetaData>
 
-#include <QTextStream>
-#include <QDomElement>
+#include <QAbstractItemView>
 #include <QApplication>
+#include <QDomElement>
 #include <QClipboard>
 #include <QFileDialog>
-#include <QAbstractItemView>
+#include <QInputDialog>
+#include <QSaveFile>
 #include <QStandardPaths>
 #include <QTimer>
 #include <QTemporaryFile>
+#include <QTextStream>
 
 #ifdef HAVE_KWORKSPACE
 #include <QDBusConnection>
@@ -417,7 +419,7 @@ QList<TransferHandler *> KGet::selectedTransfers()
 
     QModelIndexList selectedIndexes = m_selectionModel->selectedRows();
     //sort the indexes as this can speed up operations like deleting etc.
-    qSort(selectedIndexes.begin(), selectedIndexes.end());
+    std::sort(selectedIndexes.begin(), selectedIndexes.end());
 
     foreach(const QModelIndex &currentIndex, selectedIndexes)
     {
