@@ -17,7 +17,7 @@
 #include "core/plugin/transferfactory.h"
 #include "core/scheduler.h"
 
-#include <kiconloader.h>
+#include <KIconLoader>
 #include <KLocalizedString>
 
 #include <QDomElement>
@@ -87,7 +87,7 @@ bool Transfer::setDirectory(const QUrl& newDirectory)
 {
     Q_UNUSED(newDirectory)
 
-    //the standard implemention always returns false
+    //the standard implementation always returns false
     return false;
 }
 
