@@ -22,10 +22,13 @@
 #include "dbus/dbustransferwrapper.h"
 #include "settings.h"
 #include "transfergroupscheduler.h"
-
 #include "kget_debug.h"
-#include <qdebug.h>
-#include <klocale.h>
+
+#include <algorithm>
+
+#include <QDebug>
+
+#include <KLocalizedString>
 #include <KIO/Global>
 
 ItemMimeData::ItemMimeData()
@@ -575,7 +578,7 @@ QMimeData * TransferTreeModel::mimeData(const QModelIndexList &indexes) const
     ItemMimeData *mimeData = new ItemMimeData();
 
     QModelIndexList sortedIndexes = indexes;
-    qSort(sortedIndexes.begin(), sortedIndexes.end(), qGreater<QModelIndex>());
+    std::sort(sortedIndexes.begin(), sortedIndexes.end(), [](const QModelIndex &a, const QModelIndex &b) { return b < a; });
     foreach (const QModelIndex &index, sortedIndexes) {
         if (index.isValid() && index.column() == 0 && index.parent().isValid()) {
             ModelItem *item = itemFromIndex(index);
@@ -596,7 +599,7 @@ bool TransferTreeModel::dropMimeData(const QMimeData * mdata, Qt::DropAction act
 
     const ItemMimeData *itemData = qobject_cast<const ItemMimeData*>(mdata);
     if (!itemData) {
-        qCWarning(KGET_DEBUG) << "Unsuported mime data dropped.";
+        qCWarning(KGET_DEBUG) << "Unsupported mime data dropped.";
         return false;
     }
 
