@@ -23,7 +23,7 @@
 #include <QStringList>
 
 #include "kget_debug.h"
-#include <qdebug.h>
+#include <QDebug>
 #include <QIcon>
 #include <KLocalizedString>
 
