@@ -24,26 +24,26 @@
 #include <QFile>
 #include <QSignalSpy>
 #include <QtTest>
+#include <QUrl>
+#include <QTemporaryFile>
 
 #include <KJob>
-#include <KTemporaryFile>
-#include <KUrl>
 
 void FileDeleterTest::fileDeleterTest()
 {
     //nothing started to delete yet
-    QVERIFY(!FileDeleter::isFileBeingDeleted(KUrl()));
-    QVERIFY(!FileDeleter::isFileBeingDeleted(KUrl("/tmp/aFile")));
+    QVERIFY(!FileDeleter::isFileBeingDeleted(QUrl()));
+    QVERIFY(!FileDeleter::isFileBeingDeleted(QUrl::fromLocalFile("/tmp/aFile")));
 
     //create file that is going to be deleted
-    KTemporaryFile file1;
+    QTemporaryFile file1;
     file1.setAutoRemove(false);
     QVERIFY(file1.open());
     const QString fileUrl1 = file1.fileName();
     QVERIFY(QFile::exists(fileUrl1));
 
     //nothing started to delete yet
-    QVERIFY(!FileDeleter::isFileBeingDeleted(KUrl(fileUrl1)));
+    QVERIFY(!FileDeleter::isFileBeingDeleted(QUrl::fromLocalFile(fileUrl1)));
 
     //create two QObjects that will receive the result signal
     SignalReceiver receiver1;
@@ -55,19 +55,19 @@ void FileDeleterTest::fileDeleterTest()
     QVERIFY(spy2.isEmpty());
 
     //delete the file
-    FileDeleter::deleteFile(KUrl(fileUrl1), &receiver1, SIGNAL(result()));
-    QVERIFY(FileDeleter::isFileBeingDeleted(KUrl(fileUrl1)));
+    FileDeleter::deleteFile(QUrl::fromLocalFile(fileUrl1), &receiver1, SIGNAL(result()));
+    QVERIFY(FileDeleter::isFileBeingDeleted(QUrl::fromLocalFile(fileUrl1)));
 
     //deleting twice with the same receiver, still the method should only be called once
-    FileDeleter::deleteFile(KUrl(fileUrl1), &receiver1, SIGNAL(result()));
+    FileDeleter::deleteFile(QUrl::fromLocalFile(fileUrl1), &receiver1, SIGNAL(result()));
 
-    KJob *job = FileDeleter::deleteFile(KUrl(fileUrl1));
+    KJob *job = FileDeleter::deleteFile(QUrl::fromLocalFile(fileUrl1));
     connect(job, SIGNAL(result(KJob*)), &receiver2, SIGNAL(result()));
 
     //removal should be done by now
     QTest::qWait(5000);
 
-    QVERIFY(!FileDeleter::isFileBeingDeleted(KUrl(fileUrl1)));
+    QVERIFY(!FileDeleter::isFileBeingDeleted(QUrl::fromLocalFile(fileUrl1)));
     QVERIFY(!QFile::exists(fileUrl1));
 
     QCOMPARE(spy1.count(), 1);
