@@ -14,8 +14,6 @@
 
 #include "kget_debug.h"
 
-#include <KFileDialog>
-
 KGET_EXPORT_PLUGIN_CONFIG(BTSettingsWidget)
 
 BTSettingsWidget::BTSettingsWidget(QWidget * parent, const QVariantList &args)
@@ -35,9 +33,7 @@ BTSettingsWidget::BTSettingsWidget(QWidget * parent, const QVariantList &args)
 void BTSettingsWidget::load()
 {
     torrentEdit->setMode(KFile::Directory);
-    torrentEdit->fileDialog()->setWindowTitle(i18n("Select a default torrent folder"));
     tempEdit->setMode(KFile::Directory);
-    tempEdit->fileDialog()->setWindowTitle(i18n("Select a default temporary folder"));
     defaults();
 }
 
