@@ -36,7 +36,7 @@
 #include <KLocalizedString>
 #include <KIconLoader>
 #include <KIO/CopyJob>
-#include <KStandardDirs>
+
 #include <KMessageBox>
 
 #include <QDir>
@@ -44,6 +44,7 @@
 #include <QFile>
 #include <QFileInfo>
 #include <QUrl>
+#include <QStandardPaths>
 
 #ifdef ERROR
 #undef ERROR
@@ -54,13 +55,18 @@ BTTransfer::BTTransfer(TransferGroup* parent, TransferFactory* factory,
                const QDomElement * e)
   : Transfer(parent, factory, scheduler, src, dest, e),
     torrent(nullptr),
-    m_tmp(KStandardDirs::locateLocal("appdata", "tmp/")),
+    m_tmp(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QStringLiteral("/tmp/")),
     m_ready(false),
     m_downloadFinished(false),
     m_movingFile(false),
     m_fileModel(nullptr),
     m_updateCounter(0)
 {
+    QString tmpDirName = QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QStringLiteral("/tmp/");
+        // make sure that the /tmp directory exists (earlier this used to be handled by KStandardDirs)
+        if (!QFileInfo::exists(tmpDirName)) {
+            QDir().mkpath(tmpDirName);
+        }
     m_directory = KIO::upUrl(m_dest);//FIXME test
 
     setCapabilities(Transfer::Cap_Moving | Transfer::Cap_Renaming | Transfer::Cap_Resuming | Transfer::Cap_SpeedLimit);
@@ -127,13 +133,14 @@ void BTTransfer::start()
         if (!m_source.isLocalFile())
         {
             qCDebug(KGET_DEBUG) << m_dest.path();
-            m_tmpTorrentFile = QString(KStandardDirs::locateLocal("appdata", "tmp/") + m_dest.fileName());
+            QString tmpDirName = QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QStringLiteral("/tmp/");
+            m_tmpTorrentFile = tmpDirName + m_dest.fileName();
             Download *download = new Download(m_source, QUrl::fromLocalFile(m_tmpTorrentFile));
 
             setStatus(Job::Stopped, i18n("Downloading Torrent File...."), SmallIcon("document-save"));
             setTransferChange(Tc_Status, true);
 
-            //m_source = KStandardDirs::locateLocal("appdata", "tmp/") + m_source.fileName();
+            //m_source = tmpDirName + m_source.fileName();
             connect(download, SIGNAL(finishedSuccessfully(QUrl,QByteArray)), SLOT(btTransferInit(QUrl,QByteArray)));
         }
         else
@@ -420,7 +427,7 @@ void BTTransfer::btTransferInit(const QUrl &src, const QByteArray &data)
     setStatus(Job::Stopped, i18n("Analyzing torrent...."), SmallIcon("document-preview")); // jpetso says: you should probably use the "process-working" icon here (from the animations category), but that's a multi-frame PNG so it's hard for me to test
     setTransferChange(Tc_Status, true);
 
-    bt::InitLog(KStandardDirs::locateLocal("appdata", "torrentlog.log"), false, false);//initialize the torrent-log
+    bt::InitLog(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QStringLiteral("/torrentlog.log"), false, false);//initialize the torrent-log
 
     bt::SetClientInfo("KGet", KGET_VERSION_MAJOR, KGET_VERSION_MINOR, KGET_VERSION_PATCH, bt::NORMAL, "KG");//Set client info to KGet
 
