@@ -23,19 +23,20 @@
 #include "core/verifier.h"
 #include "core/signature.h"
 
+#include <algorithm>
+
+#include <KConfigGroup>
 #include <KIconLoader>
 #include <KIO/DeleteJob>
 #include <KIO/RenameDialog>
 #include <KLocalizedString>
 #include <KMessageBox>
+
 #include <QDebug>
 #include <QDialog>
-
-
-#include <QFile>
 #include <QDomElement>
+#include <QFile>
 #include <QStandardPaths>
-#include <KConfigGroup>
 
 Metalink::Metalink(TransferGroup * parent, TransferFactory * factory,
                          Scheduler * scheduler, const QUrl & source, const QUrl & dest,
@@ -137,7 +138,7 @@ bool Metalink::metalinkInit(const QUrl &src, const QByteArray &data)
 
         QList<KGetMetalink::Url> urlList = (*it).resources.urls;
         //sort the urls according to their priority (highest first)
-        qSort(urlList.begin(), urlList.end(), qGreater<KGetMetalink::Url>());
+        std::sort(urlList.begin(), urlList.end(), [](const KGetMetalink::Url &a, const KGetMetalink::Url &b) { return b < a; });
 
         KIO::filesize_t fileSize = (*it).size;
         m_totalSize += fileSize;
@@ -254,8 +255,8 @@ void Metalink::startMetalink()
     {
         foreach (DataSourceFactory *factory, m_dataSourceFactory)
         {
-            //specified number of files is downloaded simultanously
-            if (m_currentFiles < MetalinkSettings::simultanousFiles())
+            //specified number of files is downloaded simultaneously
+            if (m_currentFiles < MetalinkSettings::simultaneousFiles())
             {
                 const int status = factory->status();
                 //only start factories that should be downloaded
@@ -603,11 +604,11 @@ void Metalink::load(const QDomElement *element)
 
         //start the DataSourceFactories that were Started when KGet was closed
         if (file->status() == Job::Running) {
-            if (m_currentFiles < MetalinkSettings::simultanousFiles()) {
+            if (m_currentFiles < MetalinkSettings::simultaneousFiles()) {
                 ++m_currentFiles;
                 file->start();
             } else {
-                //enough simultanous files already, so increase the number and set file to stop --> that will decrease the number again
+                //enough simultaneous files already, so increase the number and set file to stop --> that will decrease the number again
                 file->stop();
             }
         }
