@@ -21,7 +21,7 @@
 
 
 #include "kget_debug.h"
-#include <qdebug.h>
+#include <QDebug>
 #include <QDir>
 #include <QStandardPaths>
 
@@ -189,7 +189,7 @@ void MmsTransfer::slotConnectionsErrors(int connections)
 {
     /** Here is called stop() for stop the download, set a new amount of thread
      * and set m_retryDownload = true for restart the download when mmsdownload is finish and 
-     * emit a singal connected with MmsTransfer::slotResult(), see in MmsTransfer::slotResult()
+     * emit a signal connected with MmsTransfer::slotResult(), see in MmsTransfer::slotResult()
      * for understand when its started again the download.
      */
     stop();
