@@ -24,15 +24,15 @@ class TransfersView : public QTreeView
         TransfersView(QWidget * parent = nullptr);
         ~TransfersView();
 
-        void setModel(QAbstractItemModel * model);
+        void setModel(QAbstractItemModel * model) override;
 
     private:
-        void dropEvent(QDropEvent * event);
-        void rowsInserted(const QModelIndex &, int, int);
+        void dropEvent(QDropEvent * event) override;
+        void rowsInserted(const QModelIndex &, int, int) override;
 
     protected:
-        void dragMoveEvent ( QDragMoveEvent * event );
-        void rowsAboutToBeRemoved(const QModelIndex & parent, int start, int end);
+        void dragMoveEvent ( QDragMoveEvent * event ) override;
+        void rowsAboutToBeRemoved(const QModelIndex & parent, int start, int end) override;
 
     public slots:
         void closeExpandableDetails(const QModelIndex &index = QModelIndex());
@@ -43,7 +43,7 @@ class TransfersView : public QTreeView
     private slots:
         void toggleMainGroup();// show or hide the first group header if there's only one download group
         void slotShowHeaderMenu(const QPoint &point);
-        void selectionChanged(const QItemSelection & selected, const QItemSelection & deselected);
+        void selectionChanged(const QItemSelection & selected, const QItemSelection & deselected) override;
         void slotHideSection(int logicalIndex);
         void slotSectionMoved(int logicalIndex, int oldVisualIndex, int newVisualIndex);
         void slotSaveHeader();
